var NAVTREEINDEX6 =
{
"container_data_types.html#object_scope":[0,10,2,2,1],
"container_data_types.html#object_scope_and_gc":[0,10,2,2],
"data_type_declarations.html":[0,12],
"data_type_declarations.html#any_type":[0,12,50],
"data_type_declarations.html#auto_type":[0,12,51],
"data_type_declarations.html#base64binary_type":[0,12,14],
"data_type_declarations.html#binary_or_nothing_type":[0,12,33],
"data_type_declarations.html#binary_type":[0,12,6],
"data_type_declarations.html#bool_or_nothing_type":[0,12,30],
"data_type_declarations.html#bool_type":[0,12,3],
"data_type_declarations.html#classname_type":[0,12,10],
"data_type_declarations.html#classname_type_or_nothing":[0,12,37],
"data_type_declarations.html#code_or_nothing_type":[0,12,40],
"data_type_declarations.html#code_type":[0,12,25],
"data_type_declarations.html#data_or_nothing_type":[0,12,39],
"data_type_declarations.html#data_type":[0,12,24],
"data_type_declarations.html#date_or_nothing_type":[0,12,32],
"data_type_declarations.html#date_type":[0,12,5],
"data_type_declarations.html#float_or_nothing_type":[0,12,28],
"data_type_declarations.html#float_type":[0,12,1],
"data_type_declarations.html#hash_complex_or_nothing_type":[0,12,34,1],
"data_type_declarations.html#hash_complex_type":[0,12,7,1],
"data_type_declarations.html#hash_hashdecl_or_nothing_type":[0,12,34,0],
"data_type_declarations.html#hash_hashdecl_type":[0,12,7,0],
"data_type_declarations.html#hash_or_nothing_type":[0,12,34],
"data_type_declarations.html#hash_type":[0,12,7],
"data_type_declarations.html#hexbinary_type":[0,12,15],
"data_type_declarations.html#int_or_nothing_type":[0,12,27],
"data_type_declarations.html#int_type":[0,12,0],
"data_type_declarations.html#list_complex_or_nothing_type":[0,12,35,0],
"data_type_declarations.html#list_complex_type":[0,12,8,0],
"data_type_declarations.html#list_or_nothing_type":[0,12,35],
"data_type_declarations.html#list_type":[0,12,8],
"data_type_declarations.html#nothing_type":[0,12,12],
"data_type_declarations.html#null_or_nothing_type":[0,12,38],
"data_type_declarations.html#null_type":[0,12,11],
"data_type_declarations.html#number_or_nothing_type":[0,12,29],
"data_type_declarations.html#number_type":[0,12,2],
"data_type_declarations.html#object_complex_type":[0,12,9,0],
"data_type_declarations.html#object_or_nothing_type":[0,12,36],
"data_type_declarations.html#object_type":[0,12,9],
"data_type_declarations.html#reference_complex_or_nothing_type":[0,12,42,0],
"data_type_declarations.html#reference_complex_type":[0,12,26,0],
"data_type_declarations.html#reference_or_nothing_type":[0,12,42],
"data_type_declarations.html#reference_type":[0,12,26],
"data_type_declarations.html#softbinary_type":[0,12,16],
"data_type_declarations.html#softbool_or_nothing_type":[0,12,46],
"data_type_declarations.html#softbool_type":[0,12,20],
"data_type_declarations.html#softdate_or_nothing_type":[0,12,48],
"data_type_declarations.html#softdate_type":[0,12,22],
"data_type_declarations.html#softfloat_or_nothing_type":[0,12,44],
"data_type_declarations.html#softfloat_type":[0,12,18],
"data_type_declarations.html#softint_or_nothing_type":[0,12,43],
"data_type_declarations.html#softint_type":[0,12,17],
"data_type_declarations.html#softlist_complex_or_nothing_type":[0,12,49,0],
"data_type_declarations.html#softlist_complex_type":[0,12,23,0],
"data_type_declarations.html#softlist_or_nothing_type":[0,12,49],
"data_type_declarations.html#softlist_type":[0,12,23],
"data_type_declarations.html#softnumber_or_nothing_type":[0,12,45],
"data_type_declarations.html#softnumber_type":[0,12,19],
"data_type_declarations.html#softstring_or_nothing_type":[0,12,47],
"data_type_declarations.html#softstring_type":[0,12,21],
"data_type_declarations.html#string_or_nothing_type":[0,12,31],
"data_type_declarations.html#string_type":[0,12,4],
"data_type_declarations.html#timeout_or_nothing_type":[0,12,41],
"data_type_declarations.html#timeout_type":[0,12,13],
"date_time_arithmetic.html":[0,20],
"date_time_arithmetic.html#date_time_arithmetic_adding_years_months":[0,20,0],
"date_time_arithmetic.html#date_time_arithmetic_days":[0,20,1],
"date_time_arithmetic.html#date_time_arithmetic_difference":[0,20,2],
"date_time_arithmetic.html#date_time_arithmetic_leap_years":[0,20,4],
"date_time_arithmetic.html#date_time_arithmetic_zones":[0,20,3],
"deprecated.html":[2],
"desc_overview.html":[0,1],
"environment_variables.html":[0,2],
"event_handling.html":[0,31],
"event_handling.html#EVENT_CHANNEL_CLOSED":[0,31,6],
"event_handling.html#EVENT_CONNECTED":[0,31,18],
"event_handling.html#EVENT_CONNECTING":[0,31,17],
"event_handling.html#EVENT_DATA_READ":[0,31,23],
"event_handling.html#EVENT_DATA_WRITTEN":[0,31,24],
"event_handling.html#EVENT_DELETED":[0,31,7],
"event_handling.html#EVENT_FILE_OPENED":[0,31,22],
"event_handling.html#EVENT_FTP_MESSAGE_RECEIVED":[0,31,9],
"event_handling.html#EVENT_FTP_SEND_MESSAGE":[0,31,8],
"event_handling.html#EVENT_HOSTNAME_LOOKUP":[0,31,10],
"event_handling.html#EVENT_HOSTNAME_RESOLVED":[0,31,11],
"event_handling.html#EVENT_HTTP_CHUNKED_DATA_READ":[0,31,25],
"event_handling.html#EVENT_HTTP_CHUNKED_DATA_RECEIVED":[0,31,15],
"event_handling.html#EVENT_HTTP_CHUNKED_DATA_SENT":[0,31,26],
"event_handling.html#EVENT_HTTP_CHUNKED_END":[0,31,4],
"event_handling.html#EVENT_HTTP_CHUNKED_FOOTERS_SENT":[0,31,27],
"event_handling.html#EVENT_HTTP_CHUNKED_START":[0,31,3],
"event_handling.html#EVENT_HTTP_CHUNK_SIZE":[0,31,16],
"event_handling.html#EVENT_HTTP_CONTENT_LENGTH":[0,31,2],
"event_handling.html#EVENT_HTTP_FOOTERS_RECEIVED":[0,31,14],
"event_handling.html#EVENT_HTTP_HEADERS_READ":[0,31,30],
"event_handling.html#EVENT_HTTP_MESSAGE_RECEIVED":[0,31,13],
"event_handling.html#EVENT_HTTP_REDIRECT":[0,31,5],
"event_handling.html#EVENT_HTTP_SEND_MESSAGE":[0,31,12],
"event_handling.html#EVENT_OPEN_FILE":[0,31,21],
"event_handling.html#EVENT_PACKET_READ":[0,31,0],
"event_handling.html#EVENT_PACKET_SENT":[0,31,1],
"event_handling.html#EVENT_SOCKET_DATA_READ":[0,31,28],
"event_handling.html#EVENT_SOCKET_DATA_SENT":[0,31,29],
"event_handling.html#EVENT_SSL_ESTABLISHED":[0,31,20],
"event_handling.html#EVENT_START_SSL":[0,31,19],
"exception_handling.html":[0,29],
"expressions.html":[0,17],
"expressions.html#call_reference":[0,17,2],
"expressions.html#closure":[0,17,3],
"expressions.html#find":[0,17,1],
"expressions.html#implicit_arguments":[0,17,4],
"expressions.html#implicit_index":[0,17,5],
"expressions.html#static_method_calls":[0,17,0],
"functions.html":[5,3,0],
"functions.html":[5,3,0,0],
"functions_a.html":[5,3,0,1],
"functions_b.html":[5,3,0,2],
"functions_c.html":[5,3,0,3],
"functions_d.html":[5,3,0,4],
"functions_e.html":[5,3,0,5],
"functions_f.html":[5,3,0,6],
"functions_func.html":[5,3,1],
"functions_func.html":[5,3,1,0],
"functions_func_b.html":[5,3,1,1],
"functions_func_c.html":[5,3,1,2],
"functions_func_d.html":[5,3,1,3],
"functions_func_e.html":[5,3,1,4],
"functions_func_f.html":[5,3,1,5],
"functions_func_g.html":[5,3,1,6],
"functions_func_h.html":[5,3,1,7],
"functions_func_i.html":[5,3,1,8],
"functions_func_j.html":[5,3,1,9],
"functions_func_k.html":[5,3,1,10],
"functions_func_l.html":[5,3,1,11],
"functions_func_m.html":[5,3,1,12],
"functions_func_n.html":[5,3,1,13],
"functions_func_o.html":[5,3,1,14],
"functions_func_p.html":[5,3,1,15],
"functions_func_r.html":[5,3,1,16],
"functions_func_s.html":[5,3,1,17],
"functions_func_t.html":[5,3,1,18],
"functions_func_u.html":[5,3,1,19],
"functions_func_v.html":[5,3,1,20],
"functions_func_w.html":[5,3,1,21],
"functions_func_y.html":[5,3,1,22],
"functions_func_z.html":[5,3,1,23],
"functions_g.html":[5,3,0,7],
"functions_h.html":[5,3,0,8],
"functions_i.html":[5,3,0,9],
"functions_j.html":[5,3,0,10],
"functions_k.html":[5,3,0,11],
"functions_l.html":[5,3,0,12],
"functions_m.html":[5,3,0,13],
"functions_n.html":[5,3,0,14],
"functions_o.html":[5,3,0,15],
"functions_p.html":[5,3,0,16],
"functions_q.html":[5,3,0,17],
"functions_r.html":[5,3,0,18],
"functions_s.html":[5,3,0,19],
"functions_t.html":[5,3,0,20],
"functions_u.html":[5,3,0,21],
"functions_v.html":[5,3,0,22],
"functions_vars.html":[5,3,2],
"functions_w.html":[5,3,0,23],
"functions_y.html":[5,3,0,24],
"functions_z.html":[5,3,0,25],
"group___buffered_stream_reader.html":[3,3],
"group___buffered_stream_reader.html#ga5a70489b1e5c32585eb23e2a4423c8f9":[3,3,0],
"group___buffered_stream_reader.html#ga5a70489b1e5c32585eb23e2a4423c8f9":[4,0,0,926],
"group___string_concat_decoding.html":[3,53,0,2],
"group___string_concat_decoding.html#ga2b7907f990dc6c48eeff88a94c95cb8e":[4,0,0,847],
"group___string_concat_decoding.html#ga2b7907f990dc6c48eeff88a94c95cb8e":[3,53,0,2,4],
"group___string_concat_decoding.html#ga9c3dabdb0c33c28a293c10d4c1d97935":[4,0,0,843],
"group___string_concat_decoding.html#ga9c3dabdb0c33c28a293c10d4c1d97935":[3,53,0,2,0],
"group___string_concat_decoding.html#gab7af8658ed8f43f17938bad0a1cdadf4":[4,0,0,846],
"group___string_concat_decoding.html#gab7af8658ed8f43f17938bad0a1cdadf4":[3,53,0,2,3],
"group___string_concat_decoding.html#gaba30de770d3d3b3d7239096d00ae47ec":[4,0,0,845],
"group___string_concat_decoding.html#gaba30de770d3d3b3d7239096d00ae47ec":[3,53,0,2,2],
"group___string_concat_decoding.html#gac9d1ccf5b811ffa1d178baf0d0c6130e":[4,0,0,844],
"group___string_concat_decoding.html#gac9d1ccf5b811ffa1d178baf0d0c6130e":[3,53,0,2,1],
"group___string_concat_encoding.html":[3,53,0,1],
"group___string_concat_encoding.html#ga00f7bb2b329eb21572deab8578d506cf":[4,0,0,849],
"group___string_concat_encoding.html#ga00f7bb2b329eb21572deab8578d506cf":[3,53,0,1,0],
"group___string_concat_encoding.html#ga7ebe53b7b1a81353a80cc3d79a590db6":[4,0,0,850],
"group___string_concat_encoding.html#ga7ebe53b7b1a81353a80cc3d79a590db6":[3,53,0,1,1],
"group___string_concat_encoding.html#gaa1fefe1dab38a1b1b4a32d84e34fa3f4":[4,0,0,851],
"group___string_concat_encoding.html#gaa1fefe1dab38a1b1b4a32d84e34fa3f4":[3,53,0,1,2],
"group___string_concat_encoding.html#gabdfd4734aad893296b3c584c3ba1326e":[4,0,0,852],
"group___string_concat_encoding.html#gabdfd4734aad893296b3c584c3ba1326e":[3,53,0,1,3],
"group___string_concat_encoding.html#gadb85427aabfa0641ebfd5ac5186e5d9e":[4,0,0,853],
"group___string_concat_encoding.html#gadb85427aabfa0641ebfd5ac5186e5d9e":[3,53,0,1,4],
"group__boolean__constants.html":[3,19],
"group__boolean__constants.html#ga3ba2df91713a6249449347131ea526c3":[3,19,1],
"group__boolean__constants.html#ga3ba2df91713a6249449347131ea526c3":[4,0,0,1267],
"group__boolean__constants.html#ga9da2b9a8003cd3788e48305f8a00540f":[4,0,0,994],
"group__boolean__constants.html#ga9da2b9a8003cd3788e48305f8a00540f":[3,19,0],
"group__breakpoint__policy__options.html":[3,2],
"group__breakpoint__policy__options.html#ga8366f69a68ba80c2e6c4e590ffe704cd":[3,2,2],
"group__breakpoint__policy__options.html#ga8366f69a68ba80c2e6c4e590ffe704cd":[4,0,0,836],
"group__breakpoint__policy__options.html#gaa1a11d070aa6ac6f82c94ac11f2767ff":[3,2,0],
"group__breakpoint__policy__options.html#gaa1a11d070aa6ac6f82c94ac11f2767ff":[4,0,0,834],
"group__breakpoint__policy__options.html#gaf37af71a5cae3a7c5335848129732a5a":[3,2,1],
"group__breakpoint__policy__options.html#gaf37af71a5cae3a7c5335848129732a5a":[4,0,0,835],
"group__call__type__constants.html":[3,22],
"group__call__type__constants.html#ga13d2ea7b0a108b3424bdee7c7e3ab23b":[3,22,2],
"group__call__type__constants.html#ga13d2ea7b0a108b3424bdee7c7e3ab23b":[4,0,0,915],
"group__call__type__constants.html#ga7fcc1e7cbff4b6b11a2be6185c1fdb8d":[3,22,3],
"group__call__type__constants.html#ga7fcc1e7cbff4b6b11a2be6185c1fdb8d":[4,0,0,916],
"group__call__type__constants.html#gaaa8007bd02fd23500cd18eaa09db512d":[3,22,1],
"group__call__type__constants.html#gaaa8007bd02fd23500cd18eaa09db512d":[4,0,0,914],
"group__call__type__constants.html#gaff4a6d7250c5c06104dd7ae863f24248":[3,22,0],
"group__call__type__constants.html#gaff4a6d7250c5c06104dd7ae863f24248":[4,0,0,913],
"group__compression__constants.html":[3,43,0],
"group__compression__constants.html#ga5b66f8813c20f89b4555c72244ae91a6":[3,43,0,0],
"group__compression__constants.html#ga5b66f8813c20f89b4555c72244ae91a6":[4,0,0,840],
"group__compression__constants.html#gacba7ff553151bfe51acca63193990a0c":[3,43,0,1],
"group__compression__constants.html#gacba7ff553151bfe51acca63193990a0c":[4,0,0,861],
"group__compression__constants.html#gad0d06df5b25e4e03ca74b6458626d913":[3,43,0,2],
"group__compression__constants.html#gad0d06df5b25e4e03ca74b6458626d913":[4,0,0,1347],
"group__compression__transformations.html":[3,43,1],
"group__compression__transformations.html#ga0792440b22963ae236ed21a9396f840e":[3,43,1,1],
"group__compression__transformations.html#ga0792440b22963ae236ed21a9396f840e":[4,0,0,859],
"group__compression__transformations.html#ga5fbf52ae9b5e5f6b03034772f60132b3":[3,43,1,2],
"group__compression__transformations.html#ga5fbf52ae9b5e5f6b03034772f60132b3":[4,0,0,860],
"group__compression__transformations.html#ga80882b4cc21a464faa9fcb8ff324503e":[3,43,1,0],
"group__compression__transformations.html#ga80882b4cc21a464faa9fcb8ff324503e":[4,0,0,858],
"group__compresssion__functions.html":[3,43],
"group__compresssion__functions.html#ga1590535ac15c91dee832b9ffae8fa69f":[3,43,13],
"group__compresssion__functions.html#ga1590535ac15c91dee832b9ffae8fa69f":[4,0,0,311],
"group__compresssion__functions.html#ga17fffc0db986403a295dcd86520c0ee5":[4,0,0,147],
"group__compresssion__functions.html#ga17fffc0db986403a295dcd86520c0ee5":[3,43,7],
"group__compresssion__functions.html#ga19da4b839f9348ab3c9932c961a318dc":[4,0,0,145],
"group__compresssion__functions.html#ga19da4b839f9348ab3c9932c961a318dc":[3,43,5],
"group__compresssion__functions.html#ga2a5264cac8dfd0b95b4706f122c4a5cb":[4,0,0,146],
"group__compresssion__functions.html#ga2a5264cac8dfd0b95b4706f122c4a5cb":[3,43,6],
"group__compresssion__functions.html#ga2a9f569fd6d7f90bb6d4e4d99b724105":[4,0,0,193],
"group__compresssion__functions.html#ga2a9f569fd6d7f90bb6d4e4d99b724105":[3,43,11],
"group__compresssion__functions.html#ga324723f7a61a79d2ec18b4c871c062bd":[3,43,16],
"group__compresssion__functions.html#ga324723f7a61a79d2ec18b4c871c062bd":[4,0,0,442],
"group__compresssion__functions.html#ga4a4dc4e883ee617bc05418daf884bca1":[3,43,14],
"group__compresssion__functions.html#ga4a4dc4e883ee617bc05418daf884bca1":[4,0,0,440],
"group__compresssion__functions.html#ga4a509ab986c4592aa8109cf3ec98fa8b":[4,0,0,143],
"group__compresssion__functions.html#ga4a509ab986c4592aa8109cf3ec98fa8b":[3,43,3],
"group__compresssion__functions.html#ga55081981dc37ac4a0ba9b03b8453b09b":[3,43,19],
"group__compresssion__functions.html#ga55081981dc37ac4a0ba9b03b8453b09b":[4,0,0,445],
"group__compresssion__functions.html#ga5684efdbe38373331255d4984ef13c9d":[4,0,0,443],
"group__compresssion__functions.html#ga5684efdbe38373331255d4984ef13c9d":[3,43,17],
"group__compresssion__functions.html#ga5a7dd18fde0559da33f14f484656cad7":[3,43,9]
};
